@@ -253,20 +253,20 @@ DataInput::DataInput()
 {
   date->SetToCurrent();
 
-  AttachModel(date);
+  Observe(date);
 
-  AttachModel(prevDayAction);
-  AttachModel(todayAction);
-  AttachModel(nextDayAction);
+  Observe(prevDayAction);
+  Observe(todayAction);
+  Observe(nextDayAction);
 
-  //AttachModel(addFoodAction);
-  AttachModel(addWeightAction);
-  AttachModel(removeItemAction);
-  AttachModel(editItemAction);
+  //Observe(addFoodAction);
+  Observe(addWeightAction);
+  Observe(removeItemAction);
+  Observe(editItemAction);
 
-  AttachModel(trendType);
-  AttachModel(trendDirection);
-  AttachModel(refValue);
+  Observe(trendType);
+  Observe(trendDirection);
+  Observe(refValue);
 }
 
 void DataInput::CalcSize()
