@@ -40,6 +40,8 @@ private:
   Lum::OS::ColorRef valueBadColor;
   Lum::OS::ColorRef valueBadFrameColor;
 
+  Lum::OS::FontRef  font;
+
   size_t            fullDayWidth;
   size_t            smallDayWidth;
   size_t            weightUnitWidth;
@@ -67,7 +69,6 @@ private:
 
 public:
   Diagram();
-  ~Diagram();
 
   //bool SetModel(Lum::Base::Model* model);
 
