@@ -76,17 +76,17 @@ public:
     helpAction(new Lum::Model::Action()),
     aboutAction(new Lum::Model::Action())
   {
-    AttachModel(GetOpenedAction());
-    AttachModel(GetClosedAction());
+    Observe(GetOpenedAction());
+    Observe(GetClosedAction());
 
-    AttachModel(importAction);
-    AttachModel(exportAction);
-    AttachModel(backupAction);
-    AttachModel(restoreAction);
-    AttachModel(statisticsAction);
-    AttachModel(configAction);
-    AttachModel(helpAction);
-    AttachModel(aboutAction);
+    Observe(importAction);
+    Observe(exportAction);
+    Observe(backupAction);
+    Observe(restoreAction);
+    Observe(statisticsAction);
+    Observe(configAction);
+    Observe(helpAction);
+    Observe(aboutAction);
   }
 
   void PreInit()
